change_object — Camelot documentation

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- action_steps »

# change_object

class `camelot.view.action_steps.change_object.` `ChangeObject`(obj, admin=None)

  Pop up a form for the user to change an object

  Parameters: | obj – the object to change admin – an instance of an admin class to use to edit the object, None if the default is to be taken

  `get_object`()

    Use this method to get access to the object to change in unit tests

    Returns: | the object to change

class `camelot.view.action_steps.change_object.` `ChangeObjectDialog`(obj, admin, title=_('Please complete'), subtitle=_('Complete the form and press the OK button'), icon=Icon('tango/22x22/categories/preferences-system.png'), parent=None, flags=<PyQt4.QtCore.WindowFlags object at 0xaac74fc>)

  A dialog to change an object. This differs from a FormView in that it does not contains Actions, and has an OK button that is enabled when the object is valid.

  Parameters: | obj – The object to change admin – The admin class used to create a form

class `camelot.view.action_steps.change_object.` `ChangeObjects`(objects, admin)

  Pop up a list for the user to change objects

  Parameters: | objects – a list of objects to change admin – an instance of an admin class to use to edit the objects.

  `get_objects`()

    Use this method to get access to the objects to change in unit tests

    Returns: | the object to change

class `camelot.view.action_steps.change_object.` `ChangeObjectsDialog`(objects, admin, parent=None, flags=<PyQt4.QtCore.WindowFlags object at 0xaac75dc>)

  A dialog to change a list of objects. This differs from a ListView in that it does not contains Actions, and has an OK button that is enabled when all objects are valid.

  Parameters: | objects – The object to change admin – The admin class used to create a form

### Navigation

- index
- modules |
- next |
- previous |
- Camelot documentation »
- Camelot API »
- view »
- action_steps »

Comments
blog comments powered by Disqus